@@ -287,7 +287,18 @@ class StreamExecutionEnvironment(object):
 
         :return: The :class:`~pyflink.datastream.CheckpointingMode`.
         """
-        j_checkpointing_mode = self._j_stream_execution_environment.getCheckpointingMode()
+        return self.get_checkpointing_consistency_mode()
+
+    def get_checkpointing_consistency_mode(self) -> CheckpointingMode:
+        """
+        Returns the checkpointing mode (exactly-once vs. at-least-once).
+
+        Shorthand for get_checkpoint_config().get_checkpointing_mode().
+
+        :return: The :class:`~pyflink.datastream.CheckpointingMode`.
+        """
+        j_checkpointing_mode = \
+            self._j_stream_execution_environment.getCheckpointingConsistencyMode()
         return CheckpointingMode._from_j_checkpointing_mode(j_checkpointing_mode)
 
     def get_state_backend(self) -> StateBackend:
@@ -757,12 +768,11 @@ class StreamExecutionEnvironment(object):
         jars_key = jvm.org.apache.flink.configuration.PipelineOptions.JARS.key()
         env_config = jvm.org.apache.flink.python.util.PythonConfigUtil \
             .getEnvironmentConfig(self._j_stream_execution_environment)
-        old_jars_path = env_config.getString(jars_key, None)
-        old_jars_list = Configuration.parse_list_value(
-            old_jars_path,
-            jvm.org.apache.flink.configuration.GlobalConfiguration.isStandardYaml())
-        joined_jars_list = [*old_jars_list, *jars_path]
-        env_config.setString(jars_key, str(joined_jars_list))
+        old_jar_paths = env_config.getString(jars_key, None)
+        joined_jars_path = ';'.join(jars_path)
+        if old_jar_paths and old_jar_paths.strip():
+            joined_jars_path = ';'.join([old_jar_paths, joined_jars_path])
+        env_config.setString(jars_key, joined_jars_path)
 
     def add_classpaths(self, *classpaths: str):
         """
@@ -777,12 +787,10 @@ class StreamExecutionEnvironment(object):
         env_config = jvm.org.apache.flink.python.util.PythonConfigUtil \
             .getEnvironmentConfig(self._j_stream_execution_environment)
         old_classpaths = env_config.getString(classpaths_key, None)
-        old_classpaths_list = Configuration.parse_list_value(
-            old_classpaths,
-            jvm.org.apache.flink.configuration.GlobalConfiguration.isStandardYaml()
-        )
-        joined_classpaths_list = [*old_classpaths_list, *classpaths]
-        env_config.setString(classpaths_key, str(joined_classpaths_list))
+        joined_classpaths = ';'.join(list(classpaths))
+        if old_classpaths and old_classpaths.strip():
+            joined_classpaths = ';'.join([old_classpaths, joined_classpaths])
+        env_config.setString(classpaths_key, joined_classpaths)
 
     def get_default_local_parallelism(self) -> int:
         """
